@@ -68,6 +68,8 @@ ARCHIVE_URL_DICT = {
     'right_whale_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.rightwhale.v0.zip',
     'whale_shark_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_shark.v0.zip',
     'flukebook_v1': 'https://wildbookiarepository.azureedge.net/models/classifier2.flukebook.v1.zip',
+    'rightwhale_v5': 'https://wildbookiarepository.azureedge.net/models/labeler.rightwhale.v5.zip',
+    'snow_leopard_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.snow_leopard.v0.zip',
 }
 
 
@@ -435,7 +437,7 @@ def train(
     batch_size=48,
     class_weights={},
     multi=PARALLEL,
-    sample_multiplier=2.0,
+    sample_multiplier=4.0,
     allow_missing_validation_classes=False,
     **kwargs,
 ):
