@@ -44,6 +44,7 @@ class InfrLoops(object):
             python -m wbia.algo.graph.mixin_loops main_gen
 
         Doctest:
+            >>> # xdoctest: +REQUIRES(--slow)
             >>> from wbia.algo.graph.mixin_loops import *
             >>> from wbia.algo.graph.mixin_simulation import UserOracle
             >>> import wbia
@@ -85,22 +86,31 @@ class InfrLoops(object):
             # quick startup. Yield a bunch of random edges
             num = infr.params['manual.n_peek']
             user_request = []
-            for edge in ut.random_combinations(infr.aids, 2, num=num):
-                user_request += [infr._make_review_tuple(edge, None)]
-                yield user_request
+            try:
+                for edge in ut.random_combinations(infr.aids, 2, num=num):
+                    user_request += [infr._make_review_tuple(edge, None)]
+                    yield user_request
+            except StopIteration:
+                pass
 
         if infr.params['algo.hardcase']:
             infr.loop_phase = 'hardcase_init'
             # Check previously labeled edges that where the groundtruth and the
             # verifier disagree.
-            for _ in infr.hardcase_review_gen():
-                yield _
+            try:
+                for _ in infr.hardcase_review_gen():
+                    yield _
+            except StopIteration:
+                pass
 
         if infr.params['inference.enabled']:
             infr.loop_phase = 'incon_recover_init'
             # First, fix any inconsistencies
-            for _ in infr.incon_recovery_gen():
-                yield _
+            try:
+                for _ in infr.incon_recovery_gen():
+                    yield _
+            except StopIteration:
+                pass
 
         # Phase 0.2: Ensure positive redundancy (this is generally quick)
         # so the user starts seeing real work after one random review is made
@@ -108,8 +118,11 @@ class InfrLoops(object):
         if infr.params['redun.enabled'] and infr.params['redun.enforce_pos']:
             infr.loop_phase = 'pos_redun_init'
             # Fix positive redundancy of anything within the loop
-            for _ in infr.pos_redun_gen():
-                yield _
+            try:
+                for _ in infr.pos_redun_gen():
+                    yield _
+            except StopIteration:
+                pass
 
         infr.phase = 1
         if infr.params['ranking.enabled']:
@@ -119,8 +132,11 @@ class InfrLoops(object):
 
                 # Phase 1: Try to merge PCCs by searching for LNBNN candidates
                 infr.loop_phase = 'ranking_{}'.format(count)
-                for _ in infr.ranked_list_gen(use_refresh):
-                    yield _
+                try:
+                    for _ in infr.ranked_list_gen(use_refresh):
+                        yield _
+                except StopIteration:
+                    pass
 
                 terminate = infr.refresh.num_meaningful == 0
                 if terminate:
@@ -131,8 +147,11 @@ class InfrLoops(object):
                 infr.loop_phase = 'posredun_{}'.format(count)
                 if all(ut.take(infr.params, ['redun.enabled', 'redun.enforce_pos'])):
                     # Fix positive redundancy of anything within the loop
-                    for _ in infr.pos_redun_gen():
-                        yield _
+                    try:
+                        for _ in infr.pos_redun_gen():
+                            yield _
+                    except StopIteration:
+                        pass
 
                 logger.info('prob_any_remain = %r' % (infr.refresh.prob_any_remain(),))
                 logger.info(
@@ -156,8 +175,11 @@ class InfrLoops(object):
             # asking the user to do anything but resolve inconsistency.
             infr.print('Entering phase 3', 1, color='red')
             infr.loop_phase = 'negredun'
-            for _ in infr.neg_redun_gen():
-                yield _
+            try:
+                for _ in infr.neg_redun_gen():
+                    yield _
+            except StopIteration:
+                pass
 
         infr.phase = 4
         infr.print('Terminate', 1, color='red')
@@ -254,7 +276,7 @@ class InfrLoops(object):
         """
         maybe_error_edges = list(infr.maybe_error_edges())
         if len(maybe_error_edges) == 0:
-            raise StopIteration()
+            return
         infr.print('============================', color='white')
         infr.print('--- INCON RECOVER LOOP ---', color='white')
         infr.queue.clear()
