@@ -240,8 +240,13 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
             )
         # Do eager evaulation so we can catch any exceptions
         # Before executing partial code.
-        for edge in list(aug_edges):
-            yield edge
+        try:
+            for edge in list(aug_edges):
+                yield edge
+        except StopIteration:
+            pass
+        except RuntimeError:
+            pass
     except nx.NetworkXUnfeasible:
         if partial:
             # Return all available edges
@@ -253,8 +258,13 @@ def k_edge_augmentation(G, k, avail=None, weight=None, partial=False):
                 aug_edges = partial_k_edge_augmentation(
                     G, k=k, avail=avail, weight=weight
                 )
-            for edge in aug_edges:
-                yield edge
+            try:
+                for edge in aug_edges:
+                    yield edge
+            except StopIteration:
+                pass
+            except RuntimeError:
+                pass
         else:
             raise
 
@@ -1034,7 +1044,7 @@ def greedy_k_edge_augmentation(G, k, avail=None, weight=None, seed=None):
 
     done = is_k_edge_connected(G, k)
     if done:
-        raise StopIteration()
+        return
     if avail is None:
         # all edges are available
         avail_uv = list(complement_edges(G))
