@@ -390,6 +390,7 @@ SPECIES_WITH_DETECTORS = (
     'giraffe_masai',
     'giraffe_reticulated',
     'jaguar',
+    'leopard',
     'lynx',
     'manta_ray',
     'manta_ray_giant',
@@ -399,6 +400,7 @@ SPECIES_WITH_DETECTORS = (
     'seadragon_weedy',
     'seadragon_weedy+head',
     'skunk_spotted',
+    'snow_leopard',
     'turtle_green',
     'turtle_green+head',
     'turtle_hawksbill',
@@ -415,7 +417,6 @@ SPECIES_WITH_DETECTORS = (
     'zebra_mountain',
     'whale_orca',
     'whale_orca+fin_dorsal',
-    'leopard',
     'wild_dog',
     'wild_dog_dark',
     'wild_dog_light',
@@ -455,6 +456,7 @@ SPECIES_WITH_DETECTORS = (
     'orcinus_orca',
     'orcinus_orca+fin_dorsal',
     'panthera_pardus',
+    'panthera_uncia',
     'panthera_onca',
     'acinonyx_jubatus',
     'lycaon_pictus',
