@@ -1020,149 +1020,10 @@ def compute_localizations(depc, loc_orig_id_list, config=None):
 
         # Apply NMS
         if config['nms']:
-            from wbia.other import detectcore
-
-            count_old = len(bboxes)
-            if count_old > 0:
-
-                nms_dict = {}
-                nms_class_set = set(classes)
-                nms_aware = config['nms_aware']
-                if nms_aware is not None:
-                    try:
-                        nms_aware = (
-                            nms_aware.strip().lower().replace('_', '').replace('-', '')
-                        )
-                    except Exception:
-                        pass
-
-                for nms_class in nms_class_set:
-                    flag_list = classes == nms_class
-                    nms_values = {
-                        'bboxes': np.compress(flag_list, bboxes, axis=0),
-                        'thetas': np.compress(flag_list, thetas, axis=0),
-                        'confs': np.compress(flag_list, confs, axis=0),
-                        'classes': np.compress(flag_list, classes, axis=0),
-                    }
-
-                    if nms_aware in ['byclass']:
-                        nms_key = nms_class
-                    elif nms_aware in ['ispart']:
-                        nms_key = 'part' if '+' in nms_class else 'body'
-                    else:
-                        nms_key = None
-
-                    if nms_key not in nms_dict:
-                        nms_dict[nms_key] = {}
-
-                    for value_key in nms_values:
-                        nms_value = nms_values[value_key]
-                        if value_key not in nms_dict[nms_key]:
-                            nms_dict[nms_key][value_key] = []
-                        nms_dict[nms_key][value_key].append(nms_value)
-
-                for nms_key in nms_dict:
-                    nms_values = nms_dict[nms_key]
-
-                    nms_bboxes = np.vstack(nms_values['bboxes'])
-                    nms_thetas = np.hstack(nms_values['thetas'])
-                    nms_confs = np.hstack(nms_values['confs'])
-                    nms_classes = np.hstack(nms_values['classes'])
-
-                    nms_values = {
-                        'bboxes': nms_bboxes,
-                        'thetas': nms_thetas,
-                        'confs': nms_confs,
-                        'classes': nms_classes,
-                    }
-                    nms_dict[nms_key] = nms_values
-
-                for nms_key in nms_dict:
-                    nms_values = nms_dict[nms_key]
-
-                    nms_bboxes = nms_values['bboxes']
-                    nms_thetas = nms_values['thetas']
-                    nms_confs = nms_values['confs']
-                    nms_classes = nms_values['classes']
-
-                    nms_count_old = len(nms_bboxes)
-                    assert nms_count_old > 0
-
-                    coord_list = []
-                    for (xtl, ytl, width, height) in nms_bboxes:
-                        xbr = xtl + width
-                        ybr = ytl + height
-                        coord_list.append([xtl, ytl, xbr, ybr])
-                    coord_list = np.vstack(coord_list)
-                    confs_list = np.array(nms_confs)
-
-                    nms_thresh = 1.0 - config['nms_thresh']
-                    keep_indices_list = detectcore.nms(coord_list, confs_list, nms_thresh)
-                    keep_list = np.array(keep_indices_list)
-
-                    if len(keep_list) == 0:
-                        nms_bboxes = np.array([])
-                        nms_thetas = np.array([])
-                        nms_confs = np.array([])
-                        nms_classes = np.array([])
-                    else:
-                        nms_bboxes = nms_bboxes[keep_list]
-                        nms_thetas = nms_thetas[keep_list]
-                        nms_confs = nms_confs[keep_list]
-                        nms_classes = nms_classes[keep_list]
-
-                    nms_values = {
-                        'bboxes': nms_bboxes,
-                        'thetas': nms_thetas,
-                        'confs': nms_confs,
-                        'classes': nms_classes,
-                    }
-                    nms_dict[nms_key] = nms_values
-
-                    count_new = len(nms_bboxes)
-                    if VERBOSE:
-                        nms_args = (
-                            nms_key,
-                            nms_thresh,
-                            nms_count_old,
-                            count_new,
-                        )
-                        logger.info(
-                            'Filtered nms_key = %r with nms_thresh = %0.02f (%d -> %d)'
-                            % nms_args
-                        )
-
-                bboxes = []
-                thetas = []
-                confs = []
-                classes = []
-
-                for nms_key in nms_dict:
-                    nms_values = nms_dict[nms_key]
-                    nms_bboxes = nms_values['bboxes']
-                    nms_thetas = nms_values['thetas']
-                    nms_confs = nms_values['confs']
-                    nms_classes = nms_values['classes']
-
-                    if len(nms_bboxes) > 0:
-                        bboxes.append(nms_bboxes)
-                        thetas.append(nms_thetas)
-                        confs.append(nms_confs)
-                        classes.append(nms_classes)
-
-                bboxes = np.vstack(bboxes)
-                thetas = np.hstack(thetas)
-                confs = np.hstack(confs)
-                classes = np.hstack(classes)
-
-            count_new = len(bboxes)
-            if VERBOSE:
-                nms_args = (
-                    nms_thresh,
-                    count_old,
-                    count_new,
-                )
-                logger.info('Filtered with nms_thresh = %0.02f (%d -> %d)' % nms_args)
+            indices = np.array(list(range(len(bboxes))))
+            indices, bboxes, thetas, confs, classes = ibs.nms_boxes(
+                indices, bboxes, thetas, confs, classes, verbose=VERBOSE, **config
+            )
 
         # Kill invalid images
         if config['invalid']:
