@@ -35,9 +35,25 @@ CommandLine:
     python dev.py --wshow -t query --db PZ_MTEST --qaid 110 --cfg
 """
 # TODO: ADD COPYRIGHT TAG
+try:
+    import multiprocessing as mp
+
+    mp.set_start_method('spawn')
+except RuntimeError:
+    pass
+
+try:
+    import torch  # NOQA
+    import torch.multiprocessing as tmp
+
+    tmp.set_start_method('spawn')
+except (ImportError, RuntimeError):
+    pass
+
 import logging
 import sys
 import numpy as np
+
 from wbia._devscript import devcmd, DEVCMD_FUNCTIONS, DEVPRECMD_FUNCTIONS
 import utool as ut
 from utool.util_six import get_funcname
