@@ -70,7 +70,7 @@ from wbia.control import controller_inject
 import multiprocessing
 
 
-print, rrr, profile = ut.inject2(__name__)
+print, rrr, profile = ut.inject2(__name__)  # NOQA
 # logger = logging.getLogger('wbia')
 
 
@@ -87,7 +87,7 @@ NUM_ENGINES = 1 if ut.get_argflag('--serial-job-lanes') else 2
 # VERBOSE_JOBS = (
 #     ut.get_argflag('--bg') or ut.get_argflag('--fg') or ut.get_argflag('--verbose-jobs')
 # )
-VERBOSE_JOBS = True
+VERBOSE_JOBS = False
 
 
 GLOBAL_SHELVE_LOCK = multiprocessing.Lock()
@@ -277,6 +277,16 @@ def get_job_id_list(ibs):
     return jobid_list
 
 
+@register_ibs_method
+@register_api(
+    '/api/engine/process/status/', methods=['GET', 'POST'], __api_plural_check__=False
+)
+def get_process_alive_status(ibs):
+    status_dict = ibs.job_manager.reciever.get_process_alive_status()
+    print('status_dict = %r' % (status_dict,))
+    return status_dict
+
+
 @register_ibs_method
 @register_api(
     '/api/engine/job/status/', methods=['GET', 'POST'], __api_plural_check__=False
@@ -352,6 +362,7 @@ def get_job_metadata(ibs, jobid):
         python -m wbia.web.job_engine --exec-get_job_metadata:0 --fg
 
     Example:
+        >>> # xdoctest: +REQUIRES(--slow)
         >>> # WEB_DOCTEST
         >>> from wbia.web.job_engine import *  # NOQA
         >>> import wbia
@@ -611,6 +622,24 @@ class JobBackend(object):
                 for engine in self.engine_procs[lane]:
                     assert engine.is_alive(), 'engine died too soon'
 
+    def get_process_alive_status(self):
+        status_dict = {}
+
+        if self.spawn_queue:
+            status_dict['engine_queue'] = self.engine_queue_proc.is_alive()
+            status_dict['collect_queue'] = self.collect_queue_proc.is_alive()
+
+        if self.spawn_collector:
+            status_dict['collector'] = self.collect_proc.is_alive()
+
+        if self.spawn_engine:
+            for lane in self.engine_procs:
+                for id_, engine in enumerate(self.engine_procs[lane]):
+                    engine_str = 'engine.%s.%s' % (lane, id_)
+                    status_dict[engine_str] = engine.is_alive()
+
+        return status_dict
+
 
 def get_shelve_lock_filepath(shelve_filepath):
     shelve_lock_filepath = '%s.lock' % (shelve_filepath,)
@@ -689,13 +718,8 @@ def initialize_process_record(
     shelve_output_filepath,
     shelve_path,
     shelve_archive_path,
-    collect_pull_interface,
     jobiface_id,
 ):
-
-    collect_recieve_socket = ctx.socket(zmq.DEALER)
-    collect_recieve_socket.connect(collect_pull_interface)
-
     MAX_ATTEMPTS = 20
     ARCHIVE_DAYS = 14
 
@@ -785,23 +809,6 @@ def initialize_process_record(
         if completed or suppressed or corrupted:
             # Register the job, pass the jobcounter and jobid only
             engine_request = None
-
-            if completed:
-                status = 'completed'
-            elif suppressed:
-                status = 'suppressed'
-            else:
-                status = 'corrupted'
-
-            reply_notify = {
-                'jobid': jobid,
-                'status': status,
-                'action': 'register',
-            }
-            collect_recieve_socket.send_json(reply_notify)
-            # reply = collect_recieve_socket.recv_json()
-            # jobid_ = reply['jobid']
-            # assert jobid_ == jobid
         else:
             # We have a pending job, restart with the original request
             with ut.Indenter('[client %d] ' % (jobiface_id)):
@@ -824,9 +831,6 @@ def initialize_process_record(
 
                 ut.save_cPkl(record_filepath, record, verbose=False)
 
-    collect_recieve_socket.disconnect(collect_pull_interface)
-    collect_recieve_socket.close()
-
     values = jobcounter, jobid, engine_request, archived, completed, suppressed, corrupted
     return values
 
@@ -913,8 +917,6 @@ class JobInterface(object):
                 shelve_input_filepath_list.append(shelve_input_filepath)
                 shelve_output_filepath_list.append(shelve_output_filepath)
 
-            collect_pull_interface = jobiface.port_dict['collect_pull_url']
-
             arg_iter = list(
                 zip(
                     record_filepath_list,
@@ -922,7 +924,6 @@ class JobInterface(object):
                     shelve_output_filepath_list,
                     [shelve_path] * num_records,
                     [shelve_archive_path] * num_records,
-                    [collect_pull_interface] * num_records,
                     [jobiface.id_] * num_records,
                 )
             )
@@ -944,7 +945,7 @@ class JobInterface(object):
             num_registered, num_restarted = 0, 0
             num_completed, num_archived, num_suppressed, num_corrupted = 0, 0, 0, 0
 
-            for values in values_list:
+            for values in tqdm.tqdm(values_list):
                 (
                     jobcounter,
                     jobid,
@@ -966,11 +967,25 @@ class JobInterface(object):
                 if engine_request is None:
                     assert not archived
                     if completed:
+                        status = 'completed'
                         num_completed += 1
                     elif suppressed:
+                        status = 'suppressed'
                         num_suppressed += 1
                     else:
+                        status = 'corrupted'
                         num_corrupted += 1
+
+                    reply_notify = {
+                        'jobid': jobid,
+                        'status': status,
+                        'action': 'register',
+                    }
+                    print('Sending register: %r' % (reply_notify,))
+                    jobiface.collect_recieve_socket.send_json(reply_notify)
+                    reply = jobiface.collect_recieve_socket.recv_json()
+                    jobid_ = reply['jobid']
+                    assert jobid_ == jobid
                 else:
                     num_restarted += 1
                     restart_jobcounter_list.append(jobcounter)
@@ -1508,6 +1523,17 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
     # CALLED_FROM: engine_queue
     import wbia
 
+    try:
+        import tensorflow as tf  # NOQA
+        from keras import backend as K  # NOQA
+
+        config = tf.ConfigProto()
+        config.gpu_options.allow_growth = True
+        sess = tf.Session(config=config)
+        K.set_session(sess)
+    except (ImportError, RuntimeError):
+        pass
+
     # base_print = print  # NOQA
     print = partial(ut.colorprint, color='brightgreen')
     with ut.Indenter('[engine %s %d] ' % (lane, id_)):
@@ -1543,76 +1569,88 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
 
         try:
             while True:
-                idents, engine_request = rcv_multipart_json(engine_send_sock, print=print)
+                try:
+                    idents, engine_request = rcv_multipart_json(
+                        engine_send_sock, print=print
+                    )
 
-                action = engine_request['action']
-                jobid = engine_request['jobid']
-                args = engine_request['args']
-                kwargs = engine_request['kwargs']
-                callback_url = engine_request['callback_url']
-                callback_method = engine_request['callback_method']
-                lane_ = engine_request['lane']
+                    action = engine_request['action']
+                    jobid = engine_request['jobid']
+                    args = engine_request['args']
+                    kwargs = engine_request['kwargs']
+                    callback_url = engine_request['callback_url']
+                    callback_method = engine_request['callback_method']
+                    lane_ = engine_request['lane']
 
-                if VERBOSE_JOBS:
-                    print('\tjobid = %r' % (jobid,))
-                    print('\taction = %r' % (action,))
-                    print('\targs = %r' % (args,))
-                    print('\tkwargs = %r' % (kwargs,))
-                    print('\tlane = %r' % (lane,))
-                    print('\tlane_ = %r' % (lane_,))
+                    if VERBOSE_JOBS:
+                        print('\tjobid = %r' % (jobid,))
+                        print('\taction = %r' % (action,))
+                        print('\targs = %r' % (args,))
+                        print('\tkwargs = %r' % (kwargs,))
+                        print('\tlane = %r' % (lane,))
+                        print('\tlane_ = %r' % (lane_,))
 
-                # Notify start working
-                reply_notify = {
-                    # 'idents': idents,
-                    'jobid': jobid,
-                    'status': 'working',
-                    'action': 'notification',
-                }
-                collect_recieve_socket.send_json(reply_notify)
+                    # Notify start working
+                    reply_notify = {
+                        # 'idents': idents,
+                        'jobid': jobid,
+                        'status': 'working',
+                        'action': 'notification',
+                    }
+                    collect_recieve_socket.send_json(reply_notify)
 
-                engine_result = on_engine_request(ibs, jobid, action, args, kwargs)
-                exec_status = engine_result['exec_status']
+                    engine_result = on_engine_request(ibs, jobid, action, args, kwargs)
+                    exec_status = engine_result['exec_status']
 
-                # Notify start working
-                reply_notify = {
-                    # 'idents': idents,
-                    'jobid': jobid,
-                    'status': 'publishing',
-                    'action': 'notification',
-                }
-                collect_recieve_socket.send_json(reply_notify)
+                    # Notify start working
+                    reply_notify = {
+                        # 'idents': idents,
+                        'jobid': jobid,
+                        'status': 'publishing',
+                        'action': 'notification',
+                    }
+                    collect_recieve_socket.send_json(reply_notify)
 
-                # Store results in the collector
-                collect_request = {
-                    # 'idents': idents,
-                    'action': 'store',
-                    'jobid': jobid,
-                    'engine_result': engine_result,
-                    'callback_url': callback_url,
-                    'callback_method': callback_method,
-                }
-                # if VERBOSE_JOBS:
-                print(
-                    '...done working. pushing result to collector for jobid %s' % (jobid,)
-                )
+                    # Store results in the collector
+                    collect_request = {
+                        # 'idents': idents,
+                        'action': 'store',
+                        'jobid': jobid,
+                        'engine_result': engine_result,
+                        'callback_url': callback_url,
+                        'callback_method': callback_method,
+                    }
+                    # if VERBOSE_JOBS:
+                    print(
+                        '...done working. pushing result to collector for jobid %s'
+                        % (jobid,)
+                    )
 
-                # CALLS: collector_store
-                collect_recieve_socket.send_json(collect_request)
+                    # CALLS: collector_store
+                    collect_recieve_socket.send_json(collect_request)
 
-                # Notify start working
-                reply_notify = {
-                    # 'idents': idents,
-                    'jobid': jobid,
-                    'status': exec_status,
-                    'action': 'notification',
-                }
-                collect_recieve_socket.send_json(reply_notify)
-
-                # We no longer need the engine result, and can clear it's memory
-                engine_request = None
-                engine_result = None
-                collect_request = None
+                    # Notify start working
+                    reply_notify = {
+                        # 'idents': idents,
+                        'jobid': jobid,
+                        'status': exec_status,
+                        'action': 'notification',
+                    }
+                    collect_recieve_socket.send_json(reply_notify)
 
+                    # We no longer need the engine result, and can clear it's memory
+                    engine_request = None
+                    engine_result = None
+                    collect_request = None
+                except KeyboardInterrupt:
+                    raise
+                except Exception as ex:
+                    result = ut.formatex(ex, keys=['jobid'], tb=True)
+                    result = ut.strip_ansi(result)
+                    print_ = partial(ut.colorprint, color='brightred')
+                    with ut.Indenter('[job engine worker error] '):
+                        print_(result)
+                    raise
         except KeyboardInterrupt:
             print('Caught ctrl+c in engine loop. Gracefully exiting')
 
@@ -1767,6 +1805,7 @@ def collector_loop(port_dict, dbdir, containerized):
                     ut.printex(ex, 'ERROR in collection')
                     print(traceback.format_exc())
                     reply = {}
+
                 send_multipart_json(collect_rout_sock, idents, reply)
 
                 idents = None
@@ -1863,6 +1902,15 @@ def on_collect_request(
     args = get_collector_shelve_filepaths(collector_data, jobid)
     collector_shelve_input_filepath, collector_shelve_output_filepath = args
 
+    print(
+        'on_collect_request action = %r, jobid = %r, status = %r'
+        % (
+            action,
+            jobid,
+            status,
+        )
+    )
+
     if action == 'notification':
         assert None not in [jobid, runtime_lock_filepath]
 
